Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Instance ¶
type Instance interface {
component.Repository
component.Factory
component.Resolver
component.Defaults
// TestID is the id of the test suite. This should supplied by the author once, and must be immutable.
TestID() string
// RunID is the id of the current run.
RunID() string
// Do not cleanup the resources after the test run.
NoCleanup() bool
// Local working directory root for creating temporary directories / files in. If left empty,
// os.TempDir() will be used.
WorkDir() string
// CreateTmpDirectory creates a temporary directory for running local programs, or storing logs.
// By default, the root of the tmp dir will be established by os.TempDir(). If workdir flag is specified,
// it will be used instead. The directory will be of the form <root>/<runID>/<name>/.
CreateTmpDirectory(name string) (string, error)
LogOptions() *log.Options
DumpState(context string)
// TODO(nmittler): Remove this.
// Evaluate the given template with environment specific template variables.
Evaluate(t testing.TB, tmpl string) string
}
Instance of a testing context.
Click to show internal directories.
Click to hide internal directories.